<?php

return[
    'ciext_settings' => [
        'pages' => [
            'emailmng_send' => [
                'label'    => 'Настройка отправки email',
                'file'     => __DIR__ . '/../docs/usr/emailmng_send.md',
                'position' => 20,
            ],
            'emailmng_tpl'  => [
                'label'    => 'Шаблоны писем',
                'file'     => __DIR__ . '/../docs/usr/emailmng_tpl.md',
                'position' => 30,
            ],
        ]
    ],
    'developer_docs' => [
        'pages' => [
            'emailmng_dev' => [
                'label'    => 'Emailmng',
                'file'     => __DIR__ . '/../docs/emailmng.md',
                'position' => 70,
                'pages'    => [
                    'emailmng_dev_install'    => [
                        'label'    => 'Установка модуля',
                        'file'     => __DIR__ . '/../docs/dev/emailmng_dev_install.md',
                        'position' => 10,
                    ],
                    'emailmng_dev_create_tpl' => [
                        'label'    => 'Шаблоны писем',
                        'file'     => __DIR__ . '/../docs/dev/emailmng_dev_create_tpl.md',
                        'position' => 20,
                    ],
                    'emailmng_dev_send'       => [
                        'label'    => 'Настройка отправки email',
                        'file'     => __DIR__ . '/../docs/dev/emailmng_dev_send.md',
                        'position' => 30,
                    ],
                ]
            ]
        ]
    ]
];
